==> aliyun-python-sdk-nlp-automl-0.0.9.tar.gz: aliyun-python-sdk-nlp-automl-0.0.9/aliyunsdknlp_automl/request/v20191111/RunPreTrainServiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdknlp_automl.endpoint import endpoint_data

class RunPreTrainServiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'nlp-automl', '2019-11-11', 'RunPreTrainService','nlpautoml')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_PredictContent(self):
		return self.get_body_params().get('PredictContent')

	def set_PredictContent(self,PredictContent):
		self.add_body_params('PredictContent', PredictContent)

	def get_ServiceVersion(self):
		return self.get_body_params().get('ServiceVersion')

	def set_ServiceVersion(self,ServiceVersion):
		self.add_body_params('ServiceVersion', ServiceVersion)

	def get_ServiceName(self):
		return self.get_body_params().get('ServiceName')

	def set_ServiceName(self,ServiceName):
		self.add_body_params('ServiceName', ServiceName)

==> aliyun-python-sdk-nlp-automl-0.0.15.tar.gz: aliyun-python-sdk-nlp-automl-0.0.15/aliyunsdknlp_automl/request/v20191111/RunPreTrainServiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdknlp_automl.endpoint import endpoint_data

class RunPreTrainServiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'nlp-automl', '2019-11-11', 'RunPreTrainService')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_PredictContent(self): # String
		return self.get_body_params().get('PredictContent')

	def set_PredictContent(self, PredictContent):  # String
		self.add_body_params('PredictContent', PredictContent)
	def get_ServiceVersion(self): # String
		return self.get_body_params().get('ServiceVersion')

	def set_ServiceVersion(self, ServiceVersion):  # String
		self.add_body_params('ServiceVersion', ServiceVersion)
	def get_ServiceName(self): # String
		return self.get_body_params().get('ServiceName')

	def set_ServiceName(self, ServiceName):  # String
		self.add_body_params('ServiceName', ServiceName)
